﻿using System;
using System.Drawing;
using System.Reflection;
using System.Resources;
using System.Windows.Forms;
using System.Windows.Forms.Integration;
using Core.License;
using Core.License.Interfaces;
using Infragistics.Controls.Editors;
using Infragistics.Documents;
using Infragistics.Documents.Parsing;
using QB;
using SQLHelpers;
using UserControls;
//using WindowsTools;


namespace ConnParameterQB;

public partial class FormMain : Form
{
    private ElementHost _ctrlHost;
    public XamSyntaxEditor SyntaxEditor;
    public Infragistics.Documents.TextDocument MyDocument; 
    private ISQLConn _sqlConn = new SQLConn();
    private ISQLQueries _query = new SQLQueries();
    private ResourceManager _rm;
    private bool _saveToFile = true;
    private bool _saveToClipboard = true;
    private Bitmap _picSaveToFile;
    private Bitmap _picSaveToClipboard;

    private Infragistics.Documents.TextDocument abc;
    public FormMain()
    {
        InitializeComponent();
        CreateParsingDoc();
        SetClipboardIcons();

    }
    private void CreateParsingDoc()
    {
        //The ElementHost is needed to host a WPF control in a winform.
        _ctrlHost = new ElementHost();
        ////////////////////BEGIN Add Editor/////////////////
        //Create the syntaxEditor and add it to the host.
        SyntaxEditor = new XamSyntaxEditor();
        _ctrlHost.Child = this.SyntaxEditor;
        ////////////////////END Add Editor///////////////////
        
        ////////////////////BEGIN Add Document/////////////////
        //The editor needs a doc inside.
        MyDocument = new Infragistics.Documents.TextDocument();
        SyntaxEditor.Document = MyDocument;
        ////////////////////END Add Document///////////////////
        
        ////////////////////BEGIN Add To Group/////////////////
        //Now add the host the the form.
        this.Controls.Add(_ctrlHost);
        //And since this is a non-visual control, we're putting it in a
        //group container so we can visually control the size.
        grpDoc.Controls.Add(_ctrlHost);
        ////////////////////END Add To Group///////////////////
        
        ////////////////////BEGIN Set Properties/////////////////
        HostProperties();
        SyntaxProperties();
        DocumentProperties();
        ////////////////////END Set Properties///////////////////
    }
    private void SyntaxProperties()
    {
        
        SyntaxEditor.Document.Language = TSqlLanguage.Instance;
        //syntaxEditor.FontSize = 12;
        //SyntaxEditor.AllowDrag = true;
        SyntaxEditor.IsLineNumberMarginVisible = true;
        //syntaxEditor.Background = new SolidColorBrush(Colors.Red);
        
        // syntaxEditor.Width = Double.MaxValue;
        // syntaxEditor.Height = Double.MaxValue;
    }
    private void HostProperties()
    {
        _ctrlHost.Dock = DockStyle.Fill;
        _ctrlHost.AutoSize = true;
        //You can't use fill and anchor at the same time.
        //_ctrlHost.Anchor = (AnchorStyles.Bottom | AnchorStyles.Right | AnchorStyles.Left | AnchorStyles.Top);
    }
    private void DocumentProperties()
    {
      
    }
    //private void ucSLAServerSelect_ComboSLA_ValueChanged(object sender, System.EventArgs e)
    //{
    //    ucSLAServerSelect.lblCollection.Text = "I did this";
    //}
    private void btnGetQuery_Click(object sender, EventArgs e)
    {
        var query = new QueryBuilder(uC21.comboSLA.Text, "DBFileProperties").Query;
        // MyDocument.InitializeText(query);
        MyDocument.InitializeText("SELECT * FROM MyTable;");
    }
    private void SetClipboardIcons()
    {
        _rm = new ResourceManager("ConnParameterQB.Images", Assembly.GetExecutingAssembly());
       ToggleSaveToFile();
       ToggleSaveToClipboard();
    }
    private void picSaveToFile_Click(object sender, EventArgs e)
    {
        ToggleSaveToFile();
    }
    private void picSaveToClipboard_Click(object sender, EventArgs e)
    {
        ToggleSaveToClipboard();
    }
    private void ToggleSaveToFile()
    {
        _saveToFile = !_saveToFile;
        _picSaveToFile = _saveToFile
            ? ConnParameterQB.Images.SaveToFileSmallActive
            : ConnParameterQB.Images.SaveToFileSmallInactive;
        picSaveToFile.Image = _picSaveToFile;
        picSaveToFile.Image = _picSaveToFile;
    }
    private void ToggleSaveToClipboard()
    {
        _saveToClipboard = !_saveToClipboard;
        _picSaveToClipboard = _saveToClipboard
            ? ConnParameterQB.Images.ClipboardActive
            : ConnParameterQB.Images.ClipboardInActive;
        picSaveToClipboard.Image = _picSaveToFile;
    }


}